diff src/emacs.c @ 64775:17ea5769514d

(endif): Convert -script into -scriptload. (standard_args): Add -scriptload. Allow -basic-display with one dash.
author Richard M. Stallman <rms@gnu.org>
date Sun, 07 Aug 2005 17:38:36 +0000
parents a0d1312ede66
children 0e4df13dd5ba 2d92f5c9d6ae
line wrap: on
line diff
--- a/src/emacs.c	Sun Aug 07 17:36:12 2005 +0000
+++ b/src/emacs.c	Sun Aug 07 17:38:36 2005 +0000
@@ -1153,9 +1153,9 @@
   if (argmatch (argv, argc, "-script", "--script", 3, &junk, &skip_args))
     {
       noninteractive = 1;	/* Set batch mode.  */
-      /* Convert --script to -l, un-skip it, and sort again so that -l will be
-	 handled in proper sequence.  */
-      argv[skip_args - 1] = "-l";
+      /* Convert --script to --scriptload, un-skip it, and sort again
+	 so that it will be handled in proper sequence.  */
+      argv[skip_args - 1] = "-scriptload";
       skip_args -= 2;
       sort_args (argc, argv);
     }
@@ -1834,7 +1834,7 @@
   { "-itype", 0, 15, 0 },
   { "-iconic", "--iconic", 15, 0 },
   { "-D", "--basic-display", 12, 0},
-  { "--basic-display", 0, 12, 0},
+  { "-basic-display", 0, 12, 0},
   { "-bg", "--background-color", 10, 1 },
   { "-background", 0, 10, 1 },
   { "-fg", "--foreground-color", 10, 1 },
@@ -1868,6 +1868,7 @@
   { "-directory", 0, 0, 1 },
   { "-l", "--load", 0, 1 },
   { "-load", 0, 0, 1 },
+  { "-scriptload", "--scriptload", 0, 1 },
   { "-f", "--funcall", 0, 1 },
   { "-funcall", 0, 0, 1 },
   { "-eval", "--eval", 0, 1 },